# Roo Code 3.11 Release Notes (2025-03-30)

This update focuses on performance enhancements, improved provider integration, and usability refinements based on community feedback.

## Fast Edits

Roo Code's default editing mechanism, which uses diffs via the [`apply_diff`](/advanced-usage/available-tools/apply-diff) tool, is now significantly faster, especially when applying multiple changes at once. This approach modifies only the necessary lines instead of rewriting the entire file, leading to quicker edits and helping prevent issues like truncated writes on large files. This reduces waiting time and improves the flow of iterative development.

Learn more about [Fast Edits](/features/fast-edits).

## API Key Balances

You can now conveniently check your current credit balance for OpenRouter and Requesty directly within the Roo Code API provider settings. This helps monitor usage without leaving the editor.
<img src="/img/v3.11/v3.11.png" alt="Roo Code v3.11 Feature Overview" width="600" />

## Project-Level MCP Config

MCP (Mode Communication Protocol) server configurations can now be defined at the project or workspace level using a `.roo/mcp.json` file within your project's root directory. This allows for tailored MCP setups specific to different projects and takes precedence over global MCP settings. You can manage this file directly from the MCP settings view. (Thanks aheizi!)
<img src="/img/v3.11/v3.11-1.png" alt="Project-level MCP Config file example" width="600" />

Learn more about [Editing MCP Settings Files](/features/mcp/using-mcp-in-roo#editing-mcp-settings-files).


## Improved Gemini Support

Integration with Google's Gemini models has been significantly enhanced for better reliability and capability:

*   **Smarter Retry Logic:** Roo Code now intelligently handles transient Gemini API issues. It detects rate limits (HTTP 429), uses precise retry timing provided by Gemini's error responses, applies exponential backoff for other errors, and shows a countdown timer for clarity. This results in fewer disruptions and a smoother workflow, especially during peak API usage.
*   **Improved Character Escaping:** Issues with character escaping have been resolved, ensuring proper handling of special characters in code blocks, complex JSON, and non-ASCII text. This leads to more accurate code generation and fewer syntax errors in responses.
*   **Gemini 2.5 Pro Support:** Added support for the powerful Gemini 2.5 Pro model through the GCP Vertex AI provider configuration, offering larger context windows and output capacity for more complex tasks. (Thanks nbihan-mediware!)

## Import/Export Settings

<img src="/img/settings-management/settings-management.png" alt="Export, Import, and Reset buttons in Roo Code settings" width="400" />

You can now export your Roo Code settings (API Provider Profiles, Global Settings) to a `roo-code-settings.json` file for backup or sharing, and import settings from such a file to merge configurations.


Find these options in the main Roo Code settings view. Learn more about [Import/Export/Reset Settings](/features/settings-management).

## Pin and Sort API Profiles

<img src="/img/v3.11/v3.11-2.png" alt="API Profile dropdown showing pinning and sorting options" width="250" />

The API configuration dropdown in the settings now supports pinning your favorite profiles to the top and sorting the list for easier navigation, especially when managing multiple profiles. (Thanks jwcraig!)

Learn more about [Pinning and Sorting Profiles](/features/api-configuration-profiles#pinning-and-sorting-profiles).

## Editable Suggested Answers

When Roo asks a follow-up question using the [`ask_followup_question`](/advanced-usage/available-tools/ask-followup-question) tool, the suggested answers provided can now be edited directly in the chat interface before you accept one. This allows for quick modifications without retyping the entire response. (Thanks samhvw8!)

Learn more about [Interacting with Suggestions](/features/suggested-responses#interacting-with-suggestions).

<img src="/img/suggested-responses/suggested-responses-1.png" alt="Chat input box showing text copied from a suggested response, ready for editing" width="600" />

## General Improvements and Bug Fixes

*   **Partial File Reads:** Enhancements have been made to how Roo Code handles reading portions of large files. (Thanks KJ7LNW!)
*   **Tool-Calling Logic Refactor:** Significant internal refactoring of the tool-calling mechanism makes the codebase easier to maintain and extend. (Thanks diarmidmackenzie, bramburn, KJ7LNW, and others!)
*   **"Add to Context" Action:** This code action is now prioritized in the menu and includes the relevant line numbers for better context. (Thanks samhvw8!)
*   **External Activation Command:** A new command allows other VS Code extensions to programmatically activate or interface with Roo Code. (Thanks gtaylor!)
*   **Browser Tool:** General improvements and fixes have been made to the browser interaction tool. (Thanks afshawnlotfi!)
*   **Partial Read Info:** Information about partial file reads (when only a segment of a large file is processed) is now displayed in the chat interface.
*   **Settings Link:** A direct link to the relevant settings page has been added to the auto-approve action toolbar for quicker access.
*   **Provider Docs Links:** Links to the official documentation for various model providers have been added within the API configuration options.
*   **Custom OpenAI-Compatible Models:** Support added for using custom `o3-mini-` models with OpenAI-compatible providers. (Thanks snoyiatk!)